@@ -88,7 +88,7 @@ class Client(GoogleDatastoreClient):
         return entity_to_update
 
     @backoff.on_exception(backoff.expo, GOOGLE_EXCEPTIONS_TO_RETRY, max_tries=5)
-    def save_entity_with_transactions(self, entity_id: int, updated_properties: Dict, kind: str) -> None:
+    def save_entity_with_transactions(self, entity_id: Union[int, str], updated_properties: Dict, kind: str) -> None:
         """Update an entity while ensuring atomicity"""
         for _ in range(5):
             try:
